==> thousandeyes_sdk_test_results-1.2.0.tar.gz: thousandeyes_sdk_test_results-1.2.0/docs/WebTransactionDetailTestResult.md <==
# WebTransactionDetailTestResult


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**var_date** | **datetime** | Data point date UTC (ISO date-time format). | [optional] [readonly] 
**round_id** | **int** | Epoch time (seconds) indicating the start time of the round | [optional] [readonly] 
**links** | [**TestResultAppLinks**](TestResultAppLinks.md) |  | [optional] 
**start_time** | **int** | Epoch time (seconds) indicating the start time of the round | [optional] [readonly] 
**end_time** | **int** | Epoch time (seconds) indicating the end time of the round | [optional] [readonly] 
**agent** | [**Agent**](Agent.md) |  | [optional] 
**component_errors** | **int** | Number of components which did not successfully load | [optional] [readonly] 
**transaction_time** | **int** | Elapsed execution time of the web transaction script in milliseconds | [optional] [readonly] 
**error_type** | **str** | Type of error encountered; corresponds to phase of connection | [optional] [readonly] 
**error_details** | **str** | Error details, if an error were encountered | [optional] [readonly] 
**markers** | [**List[Marker]**](Marker.md) |  | [optional] 
**pages** | [**List[Page]**](Page.md) |  | [optional] 

## Example

```python
from thousandeyes_sdk.test_results.models.web_transaction_detail_test_result import WebTransactionDetailTestResult

# TODO update the JSON string below
json = "{}"
# create an instance of WebTransactionDetailTestResult from a JSON string
web_transaction_detail_test_result_instance = WebTransactionDetailTestResult.from_json(json)
# print the JSON string representation of the object
print(WebTransactionDetailTestResult.to_json())

# convert the object into a dict
web_transaction_detail_test_result_dict = web_transaction_detail_test_result_instance.to_dict()
# create an instance of WebTransactionDetailTestResult from a dict
web_transaction_detail_test_result_from_dict = WebTransactionDetailTestResult.from_dict(web_transaction_detail_test_result_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> thousandeyes_sdk_test_results-2.7.0.tar.gz: thousandeyes_sdk_test_results-2.7.0/docs/WebTransactionDetailTestResult.md <==
# WebTransactionDetailTestResult


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**var_date** | **datetime** | Data point date UTC (ISO date-time format). | [optional] [readonly] 
**round_id** | **int** | Epoch time (seconds) indicating the start time of the round | [optional] [readonly] 
**links** | [**TestResultAppLinks**](TestResultAppLinks.md) |  | [optional] 
**start_time** | **int** | Epoch time (seconds) indicating the start time of the round | [optional] [readonly] 
**end_time** | **int** | Epoch time (seconds) indicating the end time of the round | [optional] [readonly] 
**agent** | [**TestResultAgent**](TestResultAgent.md) |  | [optional] 
**component_errors** | **int** | Number of components which did not successfully load | [optional] [readonly] 
**transaction_time** | **int** | Elapsed execution time of the web transaction script in milliseconds | [optional] [readonly] 
**error_type** | **str** | Type of error encountered; corresponds to phase of connection | [optional] [readonly] 
**error_details** | **str** | Error details, if an error were encountered | [optional] [readonly] 
**markers** | [**List[Marker]**](Marker.md) |  | [optional] 
**pages** | [**List[Page]**](Page.md) |  | [optional] 

## Example

```python
from thousandeyes_sdk.test_results.models.web_transaction_detail_test_result import WebTransactionDetailTestResult

# TODO update the JSON string below
json = "{}"
# create an instance of WebTransactionDetailTestResult from a JSON string
web_transaction_detail_test_result_instance = WebTransactionDetailTestResult.from_json(json)
# print the JSON string representation of the object
print(WebTransactionDetailTestResult.to_json())

# convert the object into a dict
web_transaction_detail_test_result_dict = web_transaction_detail_test_result_instance.to_dict()
# create an instance of WebTransactionDetailTestResult from a dict
web_transaction_detail_test_result_from_dict = WebTransactionDetailTestResult.from_dict(web_transaction_detail_test_result_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
